@@ -1,4 +1,4 @@
-# Copyright (c) 1998-2002 by Jonathan Swartz. All rights reserved.
+# Copyright (c) 1998-2005 by Jonathan Swartz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -23,6 +23,12 @@ sub import
 	}
     }
 
+    #
+    # The slight weirdness to avoid calling shift in these rw subs is
+    # _intentional_.  These subs get called a lot simply to read the
+    # value, and optimizing this common case actually does achieve
+    # something.
+    #
     if ($p{read_write})
     {
 	foreach my $rw ( ref $p{read_write} ? @{ $p{read_write} } : $p{read_write} )
@@ -32,19 +38,26 @@ sub import
 		my ($name, $spec) = @$rw;
 		no strict 'refs';
 		*{"$caller\::$name"} =
-		    sub { my $s = shift;
-			  if (@_)
+		    sub { if (@_ > 1)
 			  {
+                              my $s = shift;
 			      validate_pos(@_, $spec);
 			      $s->{$name} = shift;
+                              return $s->{$name};
 			  }
-			  return $s->{$name};
+			  return $_[0]->{$name};
 		        };
 	    }
 	    else
 	    {
 		no strict 'refs';
-		*{"$caller\::$rw"} = sub { my $s = shift; $s->{$rw} = shift if @_; return $s->{$rw}; };
+		*{"$caller\::$rw"} =
+                    sub { if (@_ > 1)
+                          {
+                              $_[0]->{$rw} = $_[1];
+                          }
+                          return $_[0]->{$rw};
+                        };
 	    }
 	}
     }
@@ -97,18 +110,20 @@ HTML::Mason::MethodMaker - Used to create simple get & get/set methods in other
 
 =head1 SYNOPSIS
 
- use HTML::Mason::MethodMaker ( read_only => 'foo',
-                                read_write => [
-                                               [ bar => { type => SCALAR } ],
-                                               [ baz => { isa => 'HTML::Mason::Baz' } ],
-                                                'quux', # no validation
-                                              ],
-                                read_write_contained => { other_object =>
-                                                          [ [ 'thing1' => { isa => 'Thing1' } ],
-                                                            'thing2', # no validation
-                                                          ]
-                                                        },
-                              );
+ use HTML::Mason::MethodMaker
+     ( read_only => 'foo',
+       read_write => [
+                      [ bar => { type => SCALAR } ],
+                      [ baz => { isa => 'HTML::Mason::Baz' } ],
+                      'quux', # no validation
+                     ],
+       read_write_contained => { other_object =>
+                                 [
+                                  [ 'thing1' => { isa => 'Thing1' } ],
+                                  'thing2', # no validation
+                                 ]
+                               },
+     );
 
 =head1 DESCRIPTION
 
@@ -145,7 +160,7 @@ itself has been created.
 
 The value of the 'read_write_contained' parameter should be a hash
 reference.  The keys are the internal name of the contained object,
-such as "request" or "buffer".  The values for the keys are the same
+such as "request" or "compiler".  The values for the keys are the same
 as the parameters given for 'read_write' accessors.
 
 =head1 SEE ALSO
