@@ -1,4 +1,4 @@
-# Copyright (c) 1998-2002 by Jonathan Swartz. All rights reserved.
+# Copyright (c) 1998-2005 by Jonathan Swartz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -13,8 +13,8 @@ Params::Validate::validation_options( on_fail => sub { param_error join '', @_ }
 
 use HTML::Mason::ComponentSource;
 
-use HTML::Mason::Container;
-use base qw(HTML::Mason::Container);
+use Class::Container;
+use base qw(Class::Container);
 
 # Returns HTML::Mason::ComponentSource object
 sub get_info {
@@ -40,7 +40,7 @@ __END__
 
 =head1 NAME
 
-HTML::Mason::Resolver - base class for component path resolvers
+HTML::Mason::Resolver - Component path resolver base class
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ components.
 The HTML::Mason::Resolver provides a virtual parent class from which
 all resolver implementations should inherit.
 
-=head1 HTML::Mason::Container
+=head1 Class::Container
 
 This class is used by most of the Mason object's to manage constructor
 parameters and has-a relationships with other objects.
@@ -65,7 +65,7 @@ parameters and has-a relationships with other objects.
 See the documentation on this class for details on how to declare what
 paremeters are valid for your subclass's constructor.
 
-HTML::Mason::Resolver is a subclass of HTML::Mason::Container so you
+HTML::Mason::Resolver is a subclass of Class::Container so you
 do not need to subclass it yourself.
 
 =head1 METHODS
@@ -78,23 +78,24 @@ implement the following methods.
 =item new
 
 This method is optional.  The new method included in this class is
-simply inherited from C<HTML::Mason::Container>.
+simply inherited from C<Class::Container>.
 If you need something more complicated done in your new method you
 will need to override it in your subclass.
 
 =item get_info
 
-Given an absolute component path, returns a new
+Takes three arguments: an absolute component path, a component root key,
+and a component root path. Returns a new
 L<HTML::Mason::ComponentSource|HTML::Mason::ComponentSource> object.
 
 =item glob_path
 
-The only argument to this method is a path glob pattern, something
-like "/foo/*" or "/foo/*/bar".  Given this path, it should return a
-list of component paths for components which match this glob pattern.
+Takes two arguments: a path glob pattern, something
+like "/foo/*" or "/foo/*/bar", and a component root path. Returns
+a list of component paths for components which match this glob pattern.
 
 For example, the filesystem resolver simply appends this pattern to
-each component root in turn and calls the Perl C<glob()> function to
+the component root path and calls the Perl C<glob()> function to
 find matching files on the filesystem.
 
 =back
@@ -103,14 +104,14 @@ find matching files on the filesystem.
 
 If you are creating a new resolver that you intend to use with the
 L<HTML::Mason::ApacheHandler|HTML::Mason::ApacheHandler> module, then
-you must implement the following method as well, possibly in a
-different subclass.
+you must implement the following method as well.
 
 =over 4
 
-=item apache_request_to_comp_path ($r)
+=item apache_request_to_comp_path ($r, @comp_root_array)
 
-This method, given an Apache object, should return a component path.
+This method, given an Apache object and a list of component root pairs,
+should return a component path or undef if none exists.
 This method is used by the
 L<HTML::Mason::ApacheHandler|HTML::Mason::ApacheHandler> class to
 translate web requests into component paths.  You can omit this method
@@ -119,12 +120,6 @@ L<HTML::Mason::ApacheHandler|HTML::Mason::ApacheHandler>.
 
 =back
 
-For example, Mason includes the
-L<HTML::Mason::Resolver::File|HTML::Mason::Resolver::File> and
-HTML::Mason::Resolver::File::ApacheHandler classes.  The latter simply
-adds an implementation of the C<apache_request_to_comp_path> method
-for file based components.
-
 =head1 SEE ALSO
 
 L<HTML::Mason|HTML::Mason>
